// markdown-editor.js

class MarkdownEditor {
    constructor(textAreaId) {
      this.textArea = document.getElementById(textAreaId);
      this.previewDiv = document.createElement('div');
      this.previewDiv.classList.add('markdown-preview');
  
      // Create toolbar
      this.toolbar = document.createElement('div');
      this.toolbar.classList.add('markdown-toolbar');
  
      // Create buttons
      this.boldButton = this.createButton('B');
      this.italicButton = this.createButton('I');
      this.linkButton = this.createButton('Link');
  
      // Add buttons to toolbar
      this.toolbar.appendChild(this.boldButton);
      this.toolbar.appendChild(this.italicButton);
      this.toolbar.appendChild(this.linkButton);
  
      // Add toolbar and preview div after textarea
      this.textArea.insertAdjacentElement('afterend', this.toolbar);
      this.textArea.insertAdjacentElement('afterend', this.previewDiv);
  
      // Bind event listeners
      this.boldButton.addEventListener('click', () => this.wrapText('**', '**'));
      this.italicButton.addEventListener('click', () => this.wrapText('*', '*'));
      this.linkButton.addEventListener('click', () => this.insertLink());
      this.textArea.addEventListener('input', () => this.updatePreview());
    }
  
    createButton(label) {
      const button = document.createElement('button');
      button.textContent = label;
      return button;
    }
  
    wrapText(startTag, endTag) {
      const { selectionStart, selectionEnd } = this.textArea;
      const text = this.textArea.value;
      const selectedText = text.substring(selectionStart, selectionEnd);
      const newText = `${text.substring(0, selectionStart)}${startTag}${selectedText}${endTag}${text.substring(selectionEnd)}`;
      this.textArea.value = newText;
      this.textArea.setSelectionRange(selectionStart + startTag.length, selectionEnd + startTag.length);
      this.textArea.focus();
      this.updatePreview();
    }
  
    insertLink() {
      const url = prompt('Enter URL:');
      if (url) {
        this.wrapText(`[${url}](`, ')');
      }
    }
  
    updatePreview() {
      this.previewDiv.innerHTML = marked(this.textArea.value);
    }
  }
  
  // Usage example:
  // const editor = new MarkdownEditor('textarea-id');
  // You can then style the markdown-preview class and markdown-toolbar class as needed
  